@@ -32,3 +32,19 @@ test_that("step_with_na() works with glm() and svyglm()", {
   )
   expect_true(length(mod2$model) < length(mod$model))
 })
+
+test_that("step_with_na() works with coxph()", {
+  skip_on_cran()
+  skip_if_not_installed("survival")
+
+  df <- dplyr::tibble(
+    time = c(4, 3, 1, 1, 2, 2, 3),
+    status = c(1, 1, 1, 0, 1, 1, 0),
+    x = c(0, 2, 1, 1, 1, NA, 1),
+    sex = c(0, 0, 0, 0, 1, 1, 1)
+  )
+  mod <- survival::coxph(survival::Surv(time, status) ~ x + sex, df)
+  expect_no_error(
+    mod2 <- step_with_na(mod, full_data = df)
+  )
+})
